---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Versions (please complete the following information):**
 - Python version: [e.g. 3.6]
 - Django version: [e.g. 4.0]
 - Django-Ninja version: [e.g. 0.16.2]
 - Pydantic version: [e.g. 1.9.0]

Note you can quickly get this by runninng in `./manage.py shell` this line:
```
import django; import pydantic; import ninja; django.__version__; ninja.__version__; pydantic.__version__
```
